@@ -7,11 +7,11 @@ def invoke_backend_service(method, function_path, json_data=dict(), request=None
     error_message = None
 
     try:
-        if public == False and request is None:
+        if public is False and request is None:
             error_message = 'A private web service must receive Django\'s request'
             raise Exception
 
-        if response_token == True and request is None:
+        if response_token is True and request is None:
             error_message = 'A web service cannot expect a response token and not receive Django\'s request'
 
         if not hasattr(settings, 'BACKEND_HOST'):
@@ -48,7 +48,7 @@ def invoke_backend_service(method, function_path, json_data=dict(), request=None
         conn.close()
 
         if response.status is 204:
-            if response_token == True:
+            if response_token is True:
                 error_message = 'Backend server didn\'t respond with a token'
                 raise Exception
 
@@ -61,13 +61,13 @@ def invoke_backend_service(method, function_path, json_data=dict(), request=None
                 error_message = 'Unknown response format'
                 raise Exception
 
-            if response_token == True:
+            if response_token is True:
                 request.session[SESSION_KEY] = response_json[proxy_server.USER_TOKEN]
                 request.user.pk = response_json[proxy_server.USER_TOKEN]
                 request.session[proxy_server.EXPIRATION_DATE] = response_json[proxy_server.EXPIRATION_DATE]
 
             if response.status is 200:
-                if response_token == True and proxy_server.USER_TOKEN not in response_json:
+                if response_token is True and proxy_server.USER_TOKEN not in response_json:
                     error_message = 'Server expected user token in response'
                     raise Exception
 
@@ -81,7 +81,7 @@ def invoke_backend_service(method, function_path, json_data=dict(), request=None
                     error_message = 'Unknown error in backend server'
                     raise Exception
 
-    except Exception as e:
+    except:
         if error_message is None:
             error_message = 'Unknown error in service invocation'
 
@@ -131,7 +131,7 @@ def invoke_backend_service_as_proxy(request, method, function_path, json_data=di
         conn.close()
 
         if response.status is 204:
-            if response_token == True:
+            if response_token is True:
                 error_message = 'Backend server didn\'t respond with a token'
                 raise Exception
 
@@ -148,7 +148,7 @@ def invoke_backend_service_as_proxy(request, method, function_path, json_data=di
                 raise Exception
 
             if response.status is 200:
-                if response_token == True and proxy_server.USER_TOKEN not in response_json:
+                if response_token is True and proxy_server.USER_TOKEN not in response_json:
                     error_message = 'Server expected user token in response'
                     raise Exception
             else:
