@@ -45,7 +45,7 @@ def expose_service(methods, public=False):
                                         error_message = 'Could not invoke token validation service'
                                         raise Exception
 
-                                    if response.status_code == 403:
+                                    if response.status == 403:
                                         code = 403
                                         error_message = 'Token invalid'
                                         raise Exception
